@@ -18,6 +18,7 @@ from petisco.application.interface_service import IService
 from petisco.tasks.infrastructure.apscheduler_cron_executor import (
     APSchedulerTaskExecutor,
 )
+from petisco import __version__
 
 
 @dataclass
@@ -41,7 +42,11 @@ class Petisco(metaclass=Singleton):
         self.app_name = config.app_name
         self.app_version = config.app_version
         self.logger = config.get_logger()
-        self.info = {"app_name": self.app_name, "app_version": self.app_version}
+        self.info = {
+            "app_name": self.app_name,
+            "app_version": self.app_version,
+            "petisco_version": __version__,
+        }
         self._set_persistence()
         self._set_providers()
         self._set_events()
@@ -99,7 +104,7 @@ class Petisco(metaclass=Singleton):
             self.cron_executor.start(config_tasks)
 
     def _unschedule_tasks(self):
-        self.cron_executor.stop()
+        self.cron_executor.close()
 
     def _set_persistence(self):
         self._persistence_models = {}
@@ -181,7 +186,7 @@ class Petisco(metaclass=Singleton):
             )
 
     def _start(self):
-        self.event_subscriber.subscribe_all()
+        self.event_subscriber.start()
         self._schedule_tasks()
         self._log_status()
         self.publish_deploy_event()
@@ -195,7 +200,7 @@ class Petisco(metaclass=Singleton):
         return self.config.get_application().get_app()
 
     def stop(self):
-        self.event_subscriber.unsubscribe_all()
+        self.event_subscriber.stop()
         self._unschedule_tasks()
 
     @staticmethod
